@@ -1,7 +1,7 @@
 # chat/routing.py
 from django.urls import re_path
 
-from OpenHubAPI.data.consumers import StartConsumer
+from data.consumers import StartConsumer
 
 websocket_urlpatterns = [
     re_path(r'ws/test', StartConsumer.StartConsumer.as_asgi()), ]
